# Warning: This package is synchronized with Fedora!

%define		major 1
%define		api 1
%define		gir_major 1.0
%define		libname %mklibname ostree %{major}
%define		gir_name %mklibname ostree-gir %{gir_major}
%define		develname %mklibname -d ostree

Summary:	Tool for managing bootable, immutable filesystem trees
Name:		ostree
Version:	2017.7
Release:	%mkrel 1
Source0:	https://github.com/ostreedev/%{name}/releases/download/v%{version}/libostree-%{version}.tar.xz
Source1:	91-ostree.preset
Group:		System/Packaging
License:	LGPLv2+
URL:		https://ostree.readthedocs.io/en/latest/


BuildRequires:	git
# We always run autogen.sh
BuildRequires:	autoconf 
BuildRequires:	automake 
BuildRequires:	libtool
BuildRequires:	bison
# For docs
BuildRequires:	gtk-doc
# Core requirements
BuildRequires:	pkgconfig(libcurl)
BuildRequires:	pkgconfig(openssl)
BuildRequires:	pkgconfig(zlib)
BuildRequires:	pkgconfig(libsoup-2.4)
BuildRequires:	libattr-devel
# Extras
BuildRequires:	pkgconfig(mount)
BuildRequires:	pkgconfig(libarchive)
BuildRequires:	pkgconfig(liblzma)
BuildRequires:	pkgconfig(libselinux)
BuildRequires:	pkgconfig(libcrypto)
BuildRequires:	pkgconfig(mount)
BuildRequires:	pkgconfig(fuse)
BuildRequires:	pkgconfig(e2p)
BuildRequires:	pkgconfig(libcap)
BuildRequires:	gpgme-devel
BuildRequires:	pkgconfig(libsystemd)
BuildRequires:	pkgconfig(gobject-introspection-1.0)
BuildRequires:	dracut

# Runtime requirements
Requires:	dracut
# To ensure we have TLS
Requires:	glib-networking
Requires:	gnupg2
Requires:	systemd-units

%description
OSTree is a tool for managing bootable, immutable, versioned
filesystem trees. While it takes over some of the roles of tradtional
"package managers" like dpkg and rpm, it is not a package system; nor
is it a tool for managing full disk images. Instead, it sits between
those levels, offering a blend of the advantages (and disadvantages)
of both.

%package -n %{libname}
Summary:	Tool for managing bootable, immutable filesystem trees
Group:		System/Libraries

%description -n %{libname}
OSTree is a tool for managing bootable, immutable, versioned
filesystem trees. While it takes over some of the roles of tradtional
"package managers" like dpkg and rpm, it is not a package system; nor
is it a tool for managing full disk images. Instead, it sits between
those levels, offering a blend of the advantages (and disadvantages)
of both.

%package -n %{develname}
Summary:	Development headers for %{name}
Group:		System/Libraries
Requires:	%{name} =  %{?epoch:%{epoch}:}%{version}-%{release}
Requires:	%{libname} = %{version}-%{release}
Requires:	%{gir_name} = %{version}-%{release}

%description -n %{develname}
This package includes the header files for the %{name} library.

%package -n %{gir_name}
Summary:	GObject Introspection interface description for %{name}
Group:		System/Libraries
Requires:	%{libname} = %{version}-%{release}

%description -n %{gir_name}
GObject Introspection interface description for %{name}.

%ifnarch s390 s390x %{arm}
%package	grub2
Summary:	GRUB2 integration for OSTree
Group:		System/Boot and Init
%ifnarch aarch64
Requires:	grub2
%else
Requires:	grub2-efi
%endif

%description grub2
GRUB2 integration for OSTree
%endif

%prep
%autosetup -n libostree-%{version} -p1

%build
env NOCONFIGURE=1 ./autogen.sh
%configure2_5x --disable-silent-rules \
	   --enable-gtk-doc \
	   --with-selinux \
	   --with-curl \
	   --with-openssl \
	   --with-dracut=yesbutnoconf
%make_build

%install
%make_install
find %{buildroot} -name '*.la' -delete
install -D -m 0644 %{SOURCE1} %{buildroot}%{_prefix}/lib/systemd/system-preset/91-ostree.preset

%post
%systemd_post ostree-remount.service

%preun
%systemd_preun ostree-remount.service

%files
%license COPYING
%doc README.md
%{_bindir}/ostree
%{_bindir}/rofiles-fuse
%{_datadir}/ostree/trusted.gpg.d
%{_sysconfdir}/ostree
%dir %{_prefix}/lib/dracut/modules.d/98ostree
%{_prefix}/lib/systemd/system/ostree*.service
%{_prefix}/lib/dracut/modules.d/98ostree/*
%{_mandir}/man*/*.*
%{_prefix}/lib/systemd/system-generators/ostree-system-generator
%{_prefix}/lib/systemd/system-preset/91-ostree.preset
%exclude %{_sysconfdir}/grub.d/*ostree
%exclude %{_libexecdir}/libostree/grub2*
%{_prefix}/lib/ostree/ostree-prepare-root
%{_prefix}/lib/ostree/ostree-remount
# Moved in git master
%{_libexecdir}/libostree/*

%files -n %{libname}
%license COPYING
%{_libdir}/lib%{name}-%{api}.so.%{major}{,.*}

%files -n %{develname}
%{_libdir}/lib*.so
%{_includedir}/*
%{_libdir}/pkgconfig/*
%dir %{_datadir}/gtk-doc/html/ostree
%{_datadir}/gtk-doc/html/ostree
%{_datadir}/gir-1.0/OSTree-1.0.gir

%files -n %{gir_name}
%{_libdir}/girepository-1.0/OSTree-%{gir_major}.typelib

%ifnarch s390 s390x %{arm}
%files grub2
%{_sysconfdir}/grub.d/*ostree
%{_libexecdir}/libostree/grub2*
%endif



%changelog
* Sat Jun 24 2017 ngompa <ngompa> 2017.7-1.mga6
+ Revision: 1108263
- Update to 2017.7

* Fri May 26 2017 ngompa <ngompa> 2017.6-1.mga6
+ Revision: 1104756
- Update to 2017.6

* Thu Apr 27 2017 ngompa <ngompa> 2017.5-1.mga6
+ Revision: 1097787
- Update to v2017.5

* Sun Jan 29 2017 ngompa <ngompa> 2017.1-1.mga6
+ Revision: 1084094
- Upgrade to 2017.1

* Wed Dec 14 2016 ngompa <ngompa> 2016.15-2.mga6
+ Revision: 1074856
- Rebuild against new gpgme

* Tue Dec 13 2016 ngompa <ngompa> 2016.15-1.mga6
+ Revision: 1074436
- Upgrade to 2016.15

  + tv <tv>
    - fix URL

* Wed Oct 26 2016 ngompa <ngompa> 2016.12-1.mga6
+ Revision: 1063584
- Upgrade to 2016.12

* Tue Oct 11 2016 ngompa <ngompa> 2016.11-1.mga6
+ Revision: 1060121
- Upgrade to 2016.11

* Mon Sep 26 2016 tv <tv> 2016.10-2.mga6
+ Revision: 1056873
- rebuild with fixed rpm-mageia-setup for missing generating typelib() requires (mga#19454)

* Sun Sep 25 2016 ngompa <ngompa> 2016.10-1.mga6
+ Revision: 1055950
- Upgrade to v2016.10
- Update dependencies
- Sync patches with Fedora (fixes rhbz#1265295, rhbz#1265295)

* Sun Jul 17 2016 ngompa <ngompa> 2016.7-1.mga6
+ Revision: 1042324
- Upgrade to 2016.7

* Tue Jun 21 2016 ngompa <ngompa> 2016.6-1.mga6
+ Revision: 1037014
- Update to 2016.6

* Tue Feb 16 2016 umeabot <umeabot> 2015.9-3.mga6
+ Revision: 961989
- Mageia 6 Mass Rebuild

* Thu Oct 08 2015 ovitters <ovitters> 2015.9-2.mga6
+ Revision: 887893
- relax runtime requirements

* Thu Oct 08 2015 ovitters <ovitters> 2015.9-1.mga6
+ Revision: 887874
- from fedora

